Signal Processing
------------------

Preprocessing
^^^^^^^^^^^^^^
*signal_simulate()*
""""""""""""""""""""
.. autofunction:: neurokit2.signal_simulate

*signal_filter()*
""""""""""""""""""
.. autofunction:: neurokit2.signal_filter

*signal_sanitize()*
""""""""""""""""""""
.. autofunction:: neurokit2.signal_sanitize

*signal_resample()*
"""""""""""""""""""""
.. autofunction:: neurokit2.signal_resample

*signal_fillmissing()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.signal_fillmissing


Transformation
^^^^^^^^^^^^^^^^
*signal_binarize()*
"""""""""""""""""""
.. autofunction:: neurokit2.signal_binarize

*signal_decompose()*
""""""""""""""""""""""
.. autofunction:: neurokit2.signal_decompose

*signal_recompose()*
""""""""""""""""""""""
.. autofunction:: neurokit2.signal_recompose

*signal_detrend()*
""""""""""""""""""""
.. autofunction:: neurokit2.signal_detrend

*signal_distort()*
""""""""""""""""""""
.. autofunction:: neurokit2.signal_distort

*signal_flatline()*
""""""""""""""""""""
.. autofunction:: neurokit2.signal_flatline

*signal_interpolate()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.signal_interpolate

*signal_merge()*
"""""""""""""""""""""
.. autofunction:: neurokit2.signal_merge

*signal_noise()*
"""""""""""""""""""""
.. autofunction:: neurokit2.signal_noise

*signal_surrogate()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.signal_surrogate


Peaks
^^^^^^^^^^^^^^^^
*signal_findpeaks()*
"""""""""""""""""""""
.. autofunction:: neurokit2.signal_findpeaks

*signal_fixpeaks()*
""""""""""""""""""""
.. autofunction:: neurokit2.signal_fixpeaks


Analysis
^^^^^^^^^^^^^^^^
*signal_autocor()*
""""""""""""""""""""
.. autofunction:: neurokit2.signal_autocor

*signal_changepoints()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.signal_changepoints

*signal_period()*
""""""""""""""""""""
.. autofunction:: neurokit2.signal_period

*signal_phase()*
""""""""""""""""""
.. autofunction:: neurokit2.signal_phase

*signal_plot()*
""""""""""""""""""
.. autofunction:: neurokit2.signal_plot

*signal_power()*
""""""""""""""""""
.. autofunction:: neurokit2.signal_power

*signal_psd()*
""""""""""""""""""
.. autofunction:: neurokit2.signal_psd

*signal_rate()*
""""""""""""""""""
.. autofunction:: neurokit2.signal_rate

*signal_smooth()*
""""""""""""""""""
.. autofunction:: neurokit2.signal_smooth

*signal_synchrony()*
""""""""""""""""""""""
.. autofunction:: neurokit2.signal_synchrony

*signal_timefrequency()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.signal_timefrequency

*signal_zerocrossings()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.signal_zerocrossings


*Any function appearing below this point is not explicitly part of the documentation and should be added. Please open an issue if there is one.*


.. automodule:: neurokit2.signal
   :members:
   :exclude-members: signal_simulate, signal_filter, signal_sanitize, signal_resample, signal_binarize, signal_decompose, signal_recompose, signal_detrend, signal_distort, signal_flatline, signal_interpolate, signal_merge, signal_noise, signal_surrogate, signal_findpeaks, signal_fixpeaks, signal_autocor, signal_changepoints, signal_period, signal_phase, signal_plot, signal_power, signal_psd, signal_rate, signal_smooth, signal_synchrony, signal_timefrequency, signal_zerocrossings